==> skrooge_1.4.0.orig.tar.bz2: skrooge-1.4.0/plugins/generic/skg_advice/skgadvicedataengine.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
/** @file
* This file defines classes SKGAdviceDataEngine.
*
* @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#ifndef SKGADVICEDATAENGINE_H
#define SKGADVICEDATAENGINE_H

#include <Plasma/DataEngine>
class SKGDocument;

class SKGAdviceDataEngine : public Plasma::DataEngine
{
    Q_OBJECT

public:

    /**
     * Reimplemented from Plasma::DataEngine
     */
    SKGAdviceDataEngine(QObject* parent, const QVariantList& args);


    /**
     * Reimplemented from Plasma::DataEngine
     */
    virtual ~SKGAdviceDataEngine();

    /**
     * Reimplemented from Plasma::DataEngine
     */
    virtual void init();


    /**
     * Reimplemented from Plasma::DataEngine
     */
    virtual bool updateSourceEvent(const QString& source);

private:
    Q_DISABLE_COPY(SKGAdviceDataEngine);

    /**
     * The document used to retrieve data
     */
    SKGDocument* document;

};

#endif // SKGADVICEDATAENGINE_H

==> skrooge-1.7.5.tar.bz2: skrooge-1.7.5/plugins/generic/skg_advice/skgadvicedataengine.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
/** @file
* This file defines classes SKGAdviceDataEngine.
*
* @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#ifndef SKGADVICEDATAENGINE_H
#define SKGADVICEDATAENGINE_H

#include <Plasma/DataEngine>
class SKGDocument;

class SKGAdviceDataEngine : public Plasma::DataEngine
{
    Q_OBJECT

public:

    /**
     * Reimplemented from Plasma::DataEngine
     */
    SKGAdviceDataEngine(QObject* parent, const QVariantList& args);


    /**
     * Reimplemented from Plasma::DataEngine
     */
    virtual ~SKGAdviceDataEngine();

    /**
     * Reimplemented from Plasma::DataEngine
     */
    virtual void init();


    /**
     * Reimplemented from Plasma::DataEngine
     */
    virtual bool updateSourceEvent(const QString& source);

private:
    Q_DISABLE_COPY(SKGAdviceDataEngine)

    /**
     * The document used to retrieve data
     */
    SKGDocument* document;

};

#endif // SKGADVICEDATAENGINE_H
